"""Concatenate approximations"""

from typing import Sequence
from ..approximation import Approximation


def concatenate(
    approximations: Sequence[Approximation],
):
    """Concatenate a sequence of approximations"""

    raise NotImplementedError("Not implemented yet")
